@@ -34,7 +34,7 @@
 #'
 #' @inheritParams ggplot2::geom_path
 #' @inheritParams ggplot2::stat_identity
-#' @inheritParams stats::density
+#' @inheritParams ggplot2::stat_density
 #'
 #' @param scale How should each sina be scaled. Corresponds to the `scale`
 #' parameter in [ggplot2::geom_violin()]? Available are:
@@ -280,7 +280,7 @@ StatSina <- ggproto('StatSina', Stat,
 
 #' @rdname geom_sina
 #' @export
-stat_sina <- function(mapping = NULL, data = NULL, geom = 'sina',
+stat_sina <- function(mapping = NULL, data = NULL, geom = 'point',
                       position = 'dodge', scale = 'area', method = 'density',
                       bw = 'nrd0', kernel = 'gaussian', maxwidth = NULL,
                       adjust = 1, bin_limit = 1, binwidth = NULL, bins = NULL,
@@ -392,7 +392,7 @@ calc_bw <- function(x, bw) {
     if (length(x) < 2)
       stop("need at least 2 points to select a bandwidth automatically", call. = FALSE)
     bw <- switch(
-      tolower(bw),
+      base::tolower(bw),
       nrd0 = stats::bw.nrd0(x),
       nrd = stats::bw.nrd(x),
       ucv = stats::bw.ucv(x),
